from ..common.common_imports import *

# from ..initial.try_loading_initial_commands import *

def examples_get(get_function ):
    """ It will try to make request using default api key and proxy if set """
    get_function()
