sample_series = f"""
file:visitors
subject:visitors
TP.ODEMGZS.BDTTOPLAM
TP.ODEMGZS.ABD
TP.ODEMGZS.ARJANTIN
TP.ODEMGZS.BREZILYA
TP.ODEMGZS.KANADA
TP.ODEMGZS.KOLOMBIYA
TP.ODEMGZS.MEKSIKA
TP.ODEMGZS.SILI
TP.ODEMGZS.VENEZUELLA
TP.ODEMGZS.DAMERIKA
TP.ODEMGZS.AMERIKATOP
TP.ODEMGZS.CEZAYIR
TP.ODEMGZS.FAS
TP.ODEMGZS.GAFRIKA
TP.ODEMGZS.LIBYA
TP.ODEMGZS.MISIR
TP.ODEMGZS.SUDAN
TP.ODEMGZS.TUNUS
TP.ODEMGZS.DAFRIKA
TP.ODEMGZS.AFRIKATOP
TP.ODEMGZS.BAE
TP.ODEMGZS.BAHREYN
TP.ODEMGZS.BANGLADES
TP.ODEMGZS.CIN
TP.ODEMGZS.ENDONEZYA
TP.ODEMGZS.FILIPINLER
TP.ODEMGZS.GKORE
TP.ODEMGZS.HINDISTAN
TP.ODEMGZS.IRAK
TP.ODEMGZS.IRAN
TP.ODEMGZS.ISRAIL
TP.ODEMGZS.JAPONYA
TP.ODEMGZS.KKTC
TP.ODEMGZS.KATAR
TP.ODEMGZS.KUVEYT
TP.ODEMGZS.LUBNAN
TP.ODEMGZS.MALEZYA
TP.ODEMGZS.PAKISTAN
TP.ODEMGZS.SINGAPUR
TP.ODEMGZS.SURIYE
TP.ODEMGZS.SUUDARABISTAN
TP.ODEMGZS.TAYLAND
TP.ODEMGZS.URDUN
TP.ODEMGZS.YEMEN
TP.ODEMGZS.DASYA
TP.ODEMGZS.ASYATOP
TP.ODEMGZS.AVUSTRALYA
TP.ODEMGZS.YENIZELLANDA
TP.ODEMGZS.OKYANUSYA
TP.ODEMGZS.MILLIYESIZ
TP.ODEMGZS.GTOPLAM
--
file:visitors2
subject:visitors2
TP.ODEMGZS.BDTTOPLAM
TP.ODEMGZS.ABD
TP.ODEMGZS.ARJANTIN
TP.ODEMGZS.BREZILYA
TP.ODEMGZS.KANADA
TP.ODEMGZS.KOLOMBIYA
TP.ODEMGZS.MEKSIKA
TP.ODEMGZS.SILI
TP.ODEMGZS.VENEZUELLA
TP.ODEMGZS.DAMERIKA
TP.ODEMGZS.AMERIKATOP
TP.ODEMGZS.CEZAYIR
TP.ODEMGZS.FAS
TP.ODEMGZS.GAFRIKA
TP.ODEMGZS.LIBYA
TP.ODEMGZS.MISIR
TP.ODEMGZS.SUDAN
TP.ODEMGZS.TUNUS
TP.ODEMGZS.DAFRIKA
TP.ODEMGZS.AFRIKATOP
TP.ODEMGZS.BAE
TP.ODEMGZS.BAHREYN
TP.ODEMGZS.BANGLADES
TP.ODEMGZS.CIN
TP.ODEMGZS.ENDONEZYA
TP.ODEMGZS.FILIPINLER
TP.ODEMGZS.GKORE
TP.ODEMGZS.HINDISTAN
TP.ODEMGZS.IRAK
TP.ODEMGZS.IRAN
TP.ODEMGZS.ISRAIL
TP.ODEMGZS.JAPONYA
TP.ODEMGZS.KKTC
TP.ODEMGZS.KATAR
TP.ODEMGZS.KUVEYT
TP.ODEMGZS.LUBNAN
TP.ODEMGZS.MALEZYA
TP.ODEMGZS.PAKISTAN
TP.ODEMGZS.SINGAPUR
TP.ODEMGZS.SURIYE
TP.ODEMGZS.SUUDARABISTAN
TP.ODEMGZS.TAYLAND
TP.ODEMGZS.URDUN
TP.ODEMGZS.YEMEN
TP.ODEMGZS.DASYA
TP.ODEMGZS.ASYATOP
TP.ODEMGZS.AVUSTRALYA
TP.ODEMGZS.YENIZELLANDA
TP.ODEMGZS.OKYANUSYA
TP.ODEMGZS.MILLIYESIZ
TP.ODEMGZS.GTOPLAM
"""
