from evdspy.EVDSlocal.tests.test_evds_classes import *
from evdspy.EVDSlocal.tests.test_main_load import *

from evdspy.EVDSlocal.tests.test_project_setup import *
from evdspy.EVDSlocal.tests.test_log_session import *
from evdspy.EVDSlocal.tests.test_requests import *

from evdspy.EVDSlocal.tests.test_apikey_checks import *
#
# from .tests.test_series_files import *
# from .tests.test_manual_series import *
